public inbox for gdb-patches@sourceware.org
 help / color / mirror / Atom feed
From: Tom Tromey <tom@tromey.com>
To: gdb-patches@sourceware.org
Cc: Tom Tromey <tom@tromey.com>
Subject: [PATCH v2 04/20] Change some uses of DW_STRING to string method
Date: Sat,  4 Apr 2020 08:43:04 -0600	[thread overview]
Message-ID: <20200404144320.18851-5-tom@tromey.com> (raw)
In-Reply-To: <20200404144320.18851-1-tom@tromey.com>

This changes some of the simpler spots to use attribute::string rather
than DW_STRING.

gdb/ChangeLog
2020-04-04  Tom Tromey  <tom@tromey.com>

	* dwarf2/read.c (partial_die_info::read)
	(dwarf2_const_value_attr, anonymous_struct_prefix, )
	(dwarf2_name, dwarf2_fetch_constant_bytes): Use
	attribute::as_string.
---
 gdb/ChangeLog     |  7 +++++
 gdb/dwarf2/read.c | 66 ++++++++++++++++++++++++++---------------------
 2 files changed, 44 insertions(+), 29 deletions(-)

diff --git a/gdb/dwarf2/read.c b/gdb/dwarf2/read.c
index 0d6ae4478ae..cd5ae3c07f6 100644
--- a/gdb/dwarf2/read.c
+++ b/gdb/dwarf2/read.c
@@ -17908,14 +17908,14 @@ partial_die_info::read (const struct die_reader_specs *reader,
 	    case DW_TAG_enumerator:
 	      /* These tags always have simple identifiers already; no need
 		 to canonicalize them.  */
-	      name = DW_STRING (&attr);
+	      name = attr.as_string ();
 	      break;
 	    default:
 	      {
 		struct objfile *objfile = dwarf2_per_objfile->objfile;
 
-		name
-		  = dwarf2_canonicalize_name (DW_STRING (&attr), cu, objfile);
+		name = dwarf2_canonicalize_name (attr.as_string (),
+						 cu, objfile);
 	      }
 	      break;
 	    }
@@ -20511,7 +20511,7 @@ dwarf2_const_value_attr (const struct attribute *attr, struct type *type,
     case DW_FORM_GNU_strp_alt:
       /* DW_STRING is already allocated on the objfile obstack, point
 	 directly to it.  */
-      *bytes = (const gdb_byte *) DW_STRING (attr);
+      *bytes = (const gdb_byte *) attr->as_string ();
       break;
     case DW_FORM_block1:
     case DW_FORM_block2:
@@ -20959,21 +20959,22 @@ anonymous_struct_prefix (struct die_info *die, struct dwarf2_cu *cu)
     return NULL;
 
   attr = dw2_linkage_name_attr (die, cu);
-  if (attr == NULL || DW_STRING (attr) == NULL)
+  const char *attr_name = attr->as_string ();
+  if (attr == NULL || attr_name == NULL)
     return NULL;
 
   /* dwarf2_name had to be already called.  */
   gdb_assert (DW_STRING_IS_CANONICAL (attr));
 
   /* Strip the base name, keep any leading namespaces/classes.  */
-  base = strrchr (DW_STRING (attr), ':');
-  if (base == NULL || base == DW_STRING (attr) || base[-1] != ':')
+  base = strrchr (attr_name, ':');
+  if (base == NULL || base == attr_name || base[-1] != ':')
     return "";
 
   struct objfile *objfile = cu->per_cu->dwarf2_per_objfile->objfile;
   return obstack_strndup (&objfile->per_bfd->storage_obstack,
-			  DW_STRING (attr),
-			  &base[-1] - DW_STRING (attr));
+			  attr_name,
+			  &base[-1] - attr_name);
 }
 
 /* Return the name of the namespace/class that DIE is defined within,
@@ -21243,7 +21244,8 @@ dwarf2_name (struct die_info *die, struct dwarf2_cu *cu)
   struct objfile *objfile = cu->per_cu->dwarf2_per_objfile->objfile;
 
   attr = dwarf2_attr (die, DW_AT_name, cu);
-  if ((!attr || !DW_STRING (attr))
+  const char *attr_name = attr == nullptr ? nullptr : attr->as_string ();
+  if (attr_name == nullptr
       && die->tag != DW_TAG_namespace
       && die->tag != DW_TAG_class_type
       && die->tag != DW_TAG_interface_type
@@ -21261,11 +21263,11 @@ dwarf2_name (struct die_info *die, struct dwarf2_cu *cu)
     case DW_TAG_enumerator:
       /* These tags always have simple identifiers already; no need
 	 to canonicalize them.  */
-      return DW_STRING (attr);
+      return attr_name;
 
     case DW_TAG_namespace:
-      if (attr != NULL && DW_STRING (attr) != NULL)
-	return DW_STRING (attr);
+      if (attr_name != nullptr)
+	return attr_name;
       return CP_ANONYMOUS_NAMESPACE_STR;
 
     case DW_TAG_class_type:
@@ -21276,25 +21278,25 @@ dwarf2_name (struct die_info *die, struct dwarf2_cu *cu)
 	 structures or unions.  These were of the form "._%d" in GCC 4.1,
 	 or simply "<anonymous struct>" or "<anonymous union>" in GCC 4.3
 	 and GCC 4.4.  We work around this problem by ignoring these.  */
-      if (attr && DW_STRING (attr)
-	  && (startswith (DW_STRING (attr), "._")
-	      || startswith (DW_STRING (attr), "<anonymous")))
+      if (attr_name != nullptr
+	  && (startswith (attr_name, "._")
+	      || startswith (attr_name, "<anonymous")))
 	return NULL;
 
       /* GCC might emit a nameless typedef that has a linkage name.  See
 	 http://gcc.gnu.org/bugzilla/show_bug.cgi?id=47510.  */
-      if (!attr || DW_STRING (attr) == NULL)
+      if (!attr || attr_name == NULL)
 	{
 	  attr = dw2_linkage_name_attr (die, cu);
-	  if (attr == NULL || DW_STRING (attr) == NULL)
+	  if (attr == NULL || attr_name == NULL)
 	    return NULL;
 
 	  /* Avoid demangling DW_STRING (attr) the second time on a second
 	     call for the same DIE.  */
 	  if (!DW_STRING_IS_CANONICAL (attr))
 	    {
 	      gdb::unique_xmalloc_ptr<char> demangled
-		(gdb_demangle (DW_STRING (attr), DMGL_TYPES));
+		(gdb_demangle (attr_name, DMGL_TYPES));
 	      if (demangled == nullptr)
 		return nullptr;
 
@@ -21302,13 +21304,14 @@ dwarf2_name (struct die_info *die, struct dwarf2_cu *cu)
 	      DW_STRING_IS_CANONICAL (attr) = 1;
 	    }
 
-	  /* Strip any leading namespaces/classes, keep only the base name.
-	     DW_AT_name for named DIEs does not contain the prefixes.  */
-	  const char *base = strrchr (DW_STRING (attr), ':');
-	  if (base && base > DW_STRING (attr) && base[-1] == ':')
+	  /* Strip any leading namespaces/classes, keep only the
+	     base name.  DW_AT_name for named DIEs does not
+	     contain the prefixes.  */
+	  const char *base = strrchr (attr_name, ':');
+	  if (base && base > attr_name && base[-1] == ':')
 	    return &base[1];
 	  else
-	    return DW_STRING (attr);
+	    return attr_name;
 	}
       break;
 
@@ -21318,11 +21321,13 @@ dwarf2_name (struct die_info *die, struct dwarf2_cu *cu)
 
   if (!DW_STRING_IS_CANONICAL (attr))
     {
-      DW_STRING (attr) = dwarf2_canonicalize_name (DW_STRING (attr), cu,
+      DW_STRING (attr) = dwarf2_canonicalize_name (attr_name, cu,
 						   objfile);
       DW_STRING_IS_CANONICAL (attr) = 1;
     }
-  return DW_STRING (attr);
+
+  /* We might have changed it just above.  */
+  return attr->as_string ();
 }
 
 /* Return the die that this die in an extension of, or NULL if there
@@ -21830,8 +21835,11 @@ dwarf2_fetch_constant_bytes (sect_offset sect_off,
     case DW_FORM_GNU_strp_alt:
       /* DW_STRING is already allocated on the objfile obstack, point
 	 directly to it.  */
-      result = (const gdb_byte *) DW_STRING (attr);
-      *len = strlen (DW_STRING (attr));
+      {
+	const char *attr_name = attr->as_string ();
+	result = (const gdb_byte *) attr_name;
+	*len = strlen (attr_name);
+      }
       break;
     case DW_FORM_block1:
     case DW_FORM_block2:
@@ -21276,25 +21278,25 @@ dwarf2_name (struct die_info *die, struct dwarf2_cu *cu)
 	    return NULL;
 
-	  /* Avoid demangling DW_STRING (attr) the second time on a second
+	  /* Avoid demangling attr_name the second time on a second
 	     call for the same DIE.  */
 	  if (!DW_STRING_IS_CANONICAL (attr))
-- 
2.17.2


  parent reply	other threads:[~2020-04-04 14:43 UTC|newest]

Thread overview: 26+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-04-04 14:43 [PATCH v2 00/20] Make DWARF attribute references safe Tom Tromey
2020-04-04 14:43 ` [PATCH v2 01/20] Add attribute::value_as_string method Tom Tromey
2020-04-04 14:43 ` [PATCH v2 02/20] Rename struct attribute accessors Tom Tromey
2020-04-04 14:43 ` [PATCH v2 03/20] Avoid using DW_* macros in dwarf2/attribute.c Tom Tromey
2020-04-04 14:43 ` Tom Tromey [this message]
2020-09-30 15:11   ` [PATCH v2 04/20] Change some uses of DW_STRING to string method Tom de Vries
2020-09-30 19:50     ` [committed][gdb] Fix regression in dwarf2_name Tom de Vries
2020-04-04 14:43 ` [PATCH v2 05/20] Remove some uses of DW_STRING_IS_CANONICAL Tom Tromey
2020-04-04 14:43 ` [PATCH v2 06/20] Remove DW_STRING and DW_STRING_IS_CANONICAL Tom Tromey
2020-04-04 14:43 ` [PATCH v2 07/20] Remove DW_BLOCK Tom Tromey
2020-04-04 14:43 ` [PATCH v2 08/20] Remove DW_SIGNATURE Tom Tromey
2020-04-04 14:43 ` [PATCH v2 09/20] Remove DW_SND Tom Tromey
2020-04-04 14:43 ` [PATCH v2 10/20] Use setter for attribute's unsigned value Tom Tromey
2020-04-04 14:43 ` [PATCH v2 11/20] Add reprocessing flag to struct attribute Tom Tromey
2020-04-04 14:43 ` [PATCH v2 12/20] Remove DW_ADDR Tom Tromey
2020-04-04 14:43 ` [PATCH v2 13/20] Change how reprocessing is done Tom Tromey
2020-04-04 14:43 ` [PATCH v2 14/20] Change how accessibility is handled in dwarf2/read.c Tom Tromey
2020-04-04 14:43 ` [PATCH v2 15/20] Add attribute::as_unsigned method Tom Tromey
2020-04-04 14:43 ` [PATCH v2 16/20] Change is_valid_DW_AT_defaulted to a method on attribute Tom Tromey
2020-04-04 14:43 ` [PATCH v2 17/20] Change die_info methods to check the attribute's form Tom Tromey
2020-04-04 14:43 ` [PATCH v2 18/20] Add attribute::as_virtuality method Tom Tromey
2020-04-04 14:43 ` [PATCH v2 19/20] Add attribute::as_boolean method Tom Tromey
2020-04-04 14:43 ` [PATCH v2 20/20] Remove DW_UNSND Tom Tromey
2020-09-30  8:35   ` Tom de Vries
2020-09-30 16:41     ` Tom Tromey
2020-09-30  2:28 ` [PATCH v2 00/20] Make DWARF attribute references safe Tom Tromey

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200404144320.18851-5-tom@tromey.com \
    --to=tom@tromey.com \
    --cc=gdb-patches@sourceware.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).